pm4py.algo.filtering.common package
===================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.filtering.common.attributes
   pm4py.algo.filtering.common.end_activities
   pm4py.algo.filtering.common.start_activities
   pm4py.algo.filtering.common.timestamp

Submodules
----------

pm4py.algo.filtering.common.filtering\_constants module
-------------------------------------------------------

.. automodule:: pm4py.algo.filtering.common.filtering_constants
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.filtering.common
   :members:
   :undoc-members:
   :show-inheritance:
